@@ -3,9 +3,13 @@ use strict;
 
 use vars qw[$NNTP $VERSION];
 use Net::NNTP;
-use Return::Value;
+BEGIN {
+  local $Return::Value::NO_CLUCK = 1;
+  require Return::Value;
+  Return::Value->import;
+}
 
-$VERSION   = '2.196';
+$VERSION   = '2.199';
 
 sub is_available {
     return   eval { require Net::NNTP }
